==> igniteui-react-inputs-18.6.1.tgz: package/esm2015/lib/XButtonBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { runOn, delegateCombine, delegateRemove, typeCast, EnumUtil, enumGetBox, markType } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { NativeUIButtonClickedEventArgs } from "igniteui-react-core";
import { NativeUIMouseEventArgs } from "igniteui-react-core";
import { NativeUIFocusEventArgs } from "igniteui-react-core";
import { NativeUIDisplayDensity_$type } from "igniteui-react-core";
import { NativeUIButtonDisplayType_$type } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
/**
 * @hidden
 */
export let XButtonBridge = /*@__PURE__*/ (() => {
    class XButtonBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.ac = null;
            this.aa = null;
            this.u = null;
            this.z = null;
            this.x = null;
            this.ae = null;
            this.y = null;
            this.af = null;
            this.v = null;
            this.ab = null;
            this.w = null;
            this.ad = null;
        }
        addHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 1:
                    e.clicked = delegateCombine(e.clicked, runOn(this, this.ag));
                    this.u = d;
                    this.z = b;
                    break;
                case 7:
                    e.mouseEnter = delegateCombine(e.mouseEnter, runOn(this, this.aj));
                    this.x = d;
                    this.ae = b;
                    break;
                case 8:
                    e.mouseLeave = delegateCombine(e.mouseLeave, runOn(this, this.ak));
                    this.y = d;
                    this.af = b;
                    break;
                case 12:
                    e.gotFocus = delegateCombine(e.gotFocus, runOn(this, this.ah));
                    this.v = d;
                    this.ab = b;
                    break;
                case 13:
                    e.lostFocus = delegateCombine(e.lostFocus, runOn(this, this.ai));
                    this.w = d;
                    this.ad = b;
                    break;
            }
        }
        removeHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 1:
                    e.clicked = delegateRemove(e.clicked, runOn(this, this.ag));
                    this.u = null;
                    this.z = null;
                    break;
                case 7:
                    e.mouseEnter = delegateRemove(e.mouseEnter, runOn(this, this.aj));
                    this.x = null;
                    this.ae = null;
                    break;
                case 8:
                    e.mouseLeave = delegateRemove(e.mouseLeave, runOn(this, this.ak));
                    this.y = null;
                    this.af = null;
                    break;
            }
        }
        ag(a, b) {
            if (this.u != null) {
                let c = new NativeUIButtonClickedEventArgs();
                this.u(this.z, c);
            }
        }
        aj(a, b) {
            if (this.x != null) {
                let c = new NativeUIMouseEventArgs();
                this.x(this.ae, c);
            }
        }
        ak(a, b) {
            if (this.y != null) {
                let c = new NativeUIMouseEventArgs();
                this.y(this.af, c);
            }
        }
        ah(a, b) {
            if (this.v != null) {
                this.v(this.ab, new NativeUIFocusEventArgs());
            }
        }
        ai(a, b) {
            if (this.w != null) {
                this.w(this.ad, ((() => {
                    let $ret = new NativeUIFocusEventArgs();
                    $ret.a = b.a;
                    return $ret;
                })()));
            }
        }
        setValue(a, b, c) {
            let d = a;
            switch (b) {
                case 3:
                    d.clearButtonContent();
                    if (typeCast(NativeUIComponent.$, c) !== null) {
                        this.ac = c;
                        d.appendButtonContent(this.ac.al);
                    }
                    else {
                        this.ac = c;
                        let e = d.view.k.createElement("span");
                        e.setText(this.ac == null ? null : this.ac.toString());
                        d.appendButtonContent(e);
                    }
                    break;
                case 1:
                    switch (EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, c)) {
                        case 0:
                            d.r = 0;
                            break;
                        case 1:
                            d.r = 1;
                            break;
                        case 2:
                            d.r = 3;
                            break;
                        case 3:
                            d.r = 2;
                            break;
                    }
                    break;
                case 18:
                    d.n = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                    break;
                case 54:
                    if (typeCast(NativeUIComponent.$, c) !== null) {
                        this.aa = c;
                        d.appendButtonContent(this.aa.al);
                    }
                    break;
                case 0:
                    switch (EnumUtil.getEnumValue(NativeUIButtonDisplayType_$type, c)) {
                        case 3:
                            d.e = 3;
                            break;
                        case 1:
                            d.e = 1;
                            break;
                        case 4:
                            d.e = 4;
                            break;
                        case 2:
                            d.e = 2;
                            break;
                        case 0:
                            d.e = 0;
                            break;
                    }
                    break;
                case 4:
                    d.at = c;
                    break;
                case 32:
                    d.disabled = c;
                    break;
                case 5:
                    d.ar = c;
                    break;
                case 6:
                    d.az = !c;
                    break;
                case 24:
                    d.p7 = c;
                    break;
                case 55:
                    d.bi = c.left;
                    d.bk = c.top;
                    d.bj = c.right;
                    d.bh = c.bottom;
                    break;
                case 57:
                    d.av = c;
                    break;
                case 56:
                    d.as = c;
                    break;
                case 58:
                    d.aq = c;
                    break;
                case 17:
                    d.kt = c;
                    break;
                case 11:
                    d.aa = c;
                    break;
            }
        }
        getValue(a, b) {
            let c = a;
            switch (b) {
                case 3: return this.ac;
                case 54: return this.aa;
                case 1:
                    switch (c.r) {
                        case 0: return enumGetBox(NativeUIDisplayDensity_$type, 0);
                        case 1: return enumGetBox(NativeUIDisplayDensity_$type, 1);
                        case 3: return enumGetBox(NativeUIDisplayDensity_$type, 2);
                        case 2: return enumGetBox(NativeUIDisplayDensity_$type, 3);
                    }
                    break;
                case 18: return enumGetBox(BaseControlTheme_$type, c.n);
                case 0:
                    switch (c.e) {
                        case 3: return enumGetBox(NativeUIButtonDisplayType_$type, 3);
                        case 1: return enumGetBox(NativeUIButtonDisplayType_$type, 1);
                        case 4: return enumGetBox(NativeUIButtonDisplayType_$type, 4);
                        case 2: return enumGetBox(NativeUIButtonDisplayType_$type, 2);
                        case 0: return enumGetBox(NativeUIButtonDisplayType_$type, 0);
                    }
                    return enumGetBox(NativeUIButtonDisplayType_$type, 0);
                case 4: return c.at;
                case 32: return c.disabled;
                case 5: return c.ar;
                case 6: return !c.az;
                case 24: return c.p7;
                case 55: return new Thickness(1, c.bi, c.bk, c.bj, c.bh);
                case 57: return c.av;
                case 56: return c.as;
                case 58: return c.aq;
                case 17: return c.kt;
            }
            return null;
        }
        setHorizontalContentAlignment(a, b) {
            switch (b) {
                case 1:
                    this.t.k5 = 1;
                    break;
                case 0:
                    this.t.k5 = 0;
                    break;
                case 2:
                    this.t.k5 = 2;
                    break;
                case 3:
                    this.t.k5 = 3;
                    break;
            }
        }
        getHorizontalContentAlignment(a) {
            switch (this.t.k5) {
                case 1: return 1;
                case 0: return 0;
                case 2: return 2;
                default: return 3;
            }
        }
        setVerticalContentAlignment(a, b) {
            switch (b) {
                case 2:
                    this.t.q9 = 2;
                    break;
                case 1:
                    this.t.q9 = 1;
                    break;
                case 3:
                    this.t.q9 = 3;
                    break;
                case 0:
                    this.t.q9 = 0;
                    break;
            }
        }
        getVerticalContentAlignment(a) {
            switch (this.t.q9) {
                case 2: return 2;
                case 1: return 1;
                case 0: return 0;
                default: return 3;
            }
        }
    }
    XButtonBridge.$t = /*@__PURE__*/ markType(XButtonBridge, 'XButtonBridge', XComponentBridge.$);
    return XButtonBridge;
})();

==> igniteui-react-inputs-18.7.3.tgz: package/esm2015/lib/XButtonBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { runOn, delegateCombine, delegateRemove, typeCast, EnumUtil, enumGetBox, markType } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { NativeUIButtonClickedEventArgs } from "igniteui-react-core";
import { NativeUIMouseEventArgs } from "igniteui-react-core";
import { NativeUIFocusEventArgs } from "igniteui-react-core";
import { NativeUIDisplayDensity_$type } from "igniteui-react-core";
import { NativeUIButtonDisplayType_$type } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
/**
 * @hidden
 */
export let XButtonBridge = /*@__PURE__*/ (() => {
    class XButtonBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.ac = null;
            this.aa = null;
            this.u = null;
            this.z = null;
            this.x = null;
            this.ae = null;
            this.y = null;
            this.af = null;
            this.v = null;
            this.ab = null;
            this.w = null;
            this.ad = null;
        }
        addHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 1:
                    e.clicked = delegateCombine(e.clicked, runOn(this, this.ag));
                    this.u = d;
                    this.z = b;
                    break;
                case 7:
                    e.mouseEnter = delegateCombine(e.mouseEnter, runOn(this, this.aj));
                    this.x = d;
                    this.ae = b;
                    break;
                case 8:
                    e.mouseLeave = delegateCombine(e.mouseLeave, runOn(this, this.ak));
                    this.y = d;
                    this.af = b;
                    break;
                case 13:
                    e.gotFocus = delegateCombine(e.gotFocus, runOn(this, this.ah));
                    this.v = d;
                    this.ab = b;
                    break;
                case 14:
                    e.lostFocus = delegateCombine(e.lostFocus, runOn(this, this.ai));
                    this.w = d;
                    this.ad = b;
                    break;
            }
        }
        removeHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 1:
                    e.clicked = delegateRemove(e.clicked, runOn(this, this.ag));
                    this.u = null;
                    this.z = null;
                    break;
                case 7:
                    e.mouseEnter = delegateRemove(e.mouseEnter, runOn(this, this.aj));
                    this.x = null;
                    this.ae = null;
                    break;
                case 8:
                    e.mouseLeave = delegateRemove(e.mouseLeave, runOn(this, this.ak));
                    this.y = null;
                    this.af = null;
                    break;
            }
        }
        ag(a, b) {
            if (this.u != null) {
                let c = new NativeUIButtonClickedEventArgs();
                this.u(this.z, c);
            }
        }
        aj(a, b) {
            if (this.x != null) {
                let c = new NativeUIMouseEventArgs();
                this.x(this.ae, c);
            }
        }
        ak(a, b) {
            if (this.y != null) {
                let c = new NativeUIMouseEventArgs();
                this.y(this.af, c);
            }
        }
        ah(a, b) {
            if (this.v != null) {
                this.v(this.ab, new NativeUIFocusEventArgs());
            }
        }
        ai(a, b) {
            if (this.w != null) {
                this.w(this.ad, ((() => {
                    let $ret = new NativeUIFocusEventArgs();
                    $ret.a = b.a;
                    return $ret;
                })()));
            }
        }
        setValue(a, b, c) {
            let d = a;
            switch (b) {
                case 3:
                    d.clearButtonContent();
                    if (typeCast(NativeUIComponent.$, c) !== null) {
                        this.ac = c;
                        d.appendButtonContent(this.ac.an);
                    }
                    else {
                        this.ac = c;
                        let e = d.view.k.createElement("span");
                        e.setText(this.ac == null ? null : this.ac.toString());
                        d.appendButtonContent(e);
                    }
                    break;
                case 1:
                    switch (EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, c)) {
                        case 0:
                            d.r = 0;
                            break;
                        case 1:
                            d.r = 1;
                            break;
                        case 2:
                            d.r = 3;
                            break;
                        case 3:
                            d.r = 2;
                            break;
                    }
                    break;
                case 18:
                    d.n = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                    break;
                case 54:
                    if (typeCast(NativeUIComponent.$, c) !== null) {
                        this.aa = c;
                        d.appendButtonContent(this.aa.an);
                    }
                    break;
                case 0:
                    switch (EnumUtil.getEnumValue(NativeUIButtonDisplayType_$type, c)) {
                        case 3:
                            d.e = 3;
                            break;
                        case 1:
                            d.e = 1;
                            break;
                        case 4:
                            d.e = 4;
                            break;
                        case 2:
                            d.e = 2;
                            break;
                        case 0:
                            d.e = 0;
                            break;
                    }
                    break;
                case 4:
                    d.at = c;
                    break;
                case 32:
                    d.disabled = c;
                    break;
                case 5:
                    d.ar = c;
                    break;
                case 6:
                    d.az = !c;
                    break;
                case 24:
                    d.p7 = c;
                    break;
                case 55:
                    d.bi = c.left;
                    d.bk = c.top;
                    d.bj = c.right;
                    d.bh = c.bottom;
                    break;
                case 57:
                    d.av = c;
                    break;
                case 56:
                    d.as = c;
                    break;
                case 58:
                    d.aq = c;
                    break;
                case 17:
                    d.kt = c;
                    break;
                case 11:
                    d.aa = c;
                    break;
                case 83:
                    d.bu = c;
                    break;
            }
        }
        getValue(a, b) {
            let c = a;
            switch (b) {
                case 3: return this.ac;
                case 54: return this.aa;
                case 1:
                    switch (c.r) {
                        case 0: return enumGetBox(NativeUIDisplayDensity_$type, 0);
                        case 1: return enumGetBox(NativeUIDisplayDensity_$type, 1);
                        case 3: return enumGetBox(NativeUIDisplayDensity_$type, 2);
                        case 2: return enumGetBox(NativeUIDisplayDensity_$type, 3);
                    }
                    break;
                case 18: return enumGetBox(BaseControlTheme_$type, c.n);
                case 0:
                    switch (c.e) {
                        case 3: return enumGetBox(NativeUIButtonDisplayType_$type, 3);
                        case 1: return enumGetBox(NativeUIButtonDisplayType_$type, 1);
                        case 4: return enumGetBox(NativeUIButtonDisplayType_$type, 4);
                        case 2: return enumGetBox(NativeUIButtonDisplayType_$type, 2);
                        case 0: return enumGetBox(NativeUIButtonDisplayType_$type, 0);
                    }
                    return enumGetBox(NativeUIButtonDisplayType_$type, 0);
                case 4: return c.at;
                case 32: return c.disabled;
                case 5: return c.ar;
                case 6: return !c.az;
                case 24: return c.p7;
                case 55: return new Thickness(1, c.bi, c.bk, c.bj, c.bh);
                case 57: return c.av;
                case 56: return c.as;
                case 58: return c.aq;
                case 17: return c.kt;
                case 83: return c.bu;
            }
            return null;
        }
        setHorizontalContentAlignment(a, b) {
            switch (b) {
                case 1:
                    this.t.k5 = 1;
                    break;
                case 0:
                    this.t.k5 = 0;
                    break;
                case 2:
                    this.t.k5 = 2;
                    break;
                case 3:
                    this.t.k5 = 3;
                    break;
            }
        }
        getHorizontalContentAlignment(a) {
            switch (this.t.k5) {
                case 1: return 1;
                case 0: return 0;
                case 2: return 2;
                default: return 3;
            }
        }
        setVerticalContentAlignment(a, b) {
            switch (b) {
                case 2:
                    this.t.q9 = 2;
                    break;
                case 1:
                    this.t.q9 = 1;
                    break;
                case 3:
                    this.t.q9 = 3;
                    break;
                case 0:
                    this.t.q9 = 0;
                    break;
            }
        }
        getVerticalContentAlignment(a) {
            switch (this.t.q9) {
                case 2: return 2;
                case 1: return 1;
                case 0: return 0;
                default: return 3;
            }
        }
        exportVisualData(a) {
            return a.d7();
        }
    }
    XButtonBridge.$t = /*@__PURE__*/ markType(XButtonBridge, 'XButtonBridge', XComponentBridge.$);
    return XButtonBridge;
})();
